@@ -1,35 +1,47 @@
 /* -----------------------------------------------------------------
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * LLNS/SMU Copyright Start
- * Copyright (c) 2002-2020, Southern Methodist University and
- * Lawrence Livermore National Security
- *
- * This work was performed under the auspices of the U.S. Department
- * of Energy by Southern Methodist University and Lawrence Livermore
- * National Laboratory under Contract DE-AC52-07NA27344.
- * Produced at Southern Methodist University and the Lawrence
- * Livermore National Laboratory.
- *
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS/SMU Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * SUNDIALS configuration header file.
  * -----------------------------------------------------------------*/
 
-#include "sundials_export.h"
+#ifndef _SUNDIALS_CONFIG_H
+#define _SUNDIALS_CONFIG_H
+
+#include "sundials/sundials_export.h"
+
+#ifndef SUNDIALS_DEPRECATED_MSG
+#  define SUNDIALS_DEPRECATED_MSG(msg) __attribute__ ((__deprecated__(msg)))
+#endif
+
+#ifndef SUNDIALS_DEPRECATED_EXPORT_MSG
+#  define SUNDIALS_DEPRECATED_EXPORT_MSG(msg) SUNDIALS_EXPORT SUNDIALS_DEPRECATED_MSG(msg)
+#endif
+
+#ifndef SUNDIALS_DEPRECATED_NO_EXPORT_MSG
+#  define SUNDIALS_DEPRECATED_NO_EXPORT_MSG(msg) SUNDIALS_NO_EXPORT SUNDIALS_DEPRECATED_MSG(msg)
+#endif
 
 /* ------------------------------------------------------------------
  * Define SUNDIALS version numbers
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "5.5.0"
-#define SUNDIALS_VERSION_MAJOR 5
-#define SUNDIALS_VERSION_MINOR 5
+#define SUNDIALS_VERSION "6.2.0"
+#define SUNDIALS_VERSION_MAJOR 6
+#define SUNDIALS_VERSION_MINOR 2
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
+#define SUNDIALS_GIT_VERSION ""
 
 
 /* ------------------------------------------------------------------
@@ -70,13 +82,37 @@
  */
 #define SUNDIALS_HAVE_POSIX_TIMERS
 
+/* BUILD CVODE with fused kernel functionality */
+/* #undef SUNDIALS_BUILD_PACKAGE_FUSED_KERNELS */
+
+/* BUILD SUNDIALS with monitoring functionalities */
+/* #undef SUNDIALS_BUILD_WITH_MONITORING */
+
+/* BUILD SUNDIALS with profiling functionalities */
+/* #undef SUNDIALS_BUILD_WITH_PROFILING */
+
+/* BUILD SUNDIALS with logging functionalities */
+#define SUNDIALS_LOGGING_LEVEL 0
+
+/* BUILD SUNDIALS with MPI-enabled logging */
+#define SUNDIALS_LOGGING_ENABLE_MPI
+
+/* Is snprintf available? */
+/* #undef SUNDIALS_COMPILER_HAS_SNPRINTF_AND_VA_COPY */
+#ifndef SUNDIALS_COMPILER_HAS_SNPRINTF_AND_VA_COPY
+#define SUNDIALS_MAX_SPRINTF_SIZE 5120
+#endif
 
 /* ------------------------------------------------------------------
  * SUNDIALS TPL macros
  * -----------------------------------------------------------------*/
 
+/* Caliper */
+/* #undef SUNDIALS_CALIPER_ENABLED */
 
-
+/* MAGMA backends */
+#define SUNDIALS_MAGMA_BACKENDS_CUDA
+/* #undef SUNDIALS_MAGMA_BACKENDS_HIP */
 
 /* Set if SUNDIALS is built with MPI support, then
  *     #define SUNDIALS_MPI_ENABLED 1
@@ -93,23 +129,15 @@
   */
 /* #undef SUNDIALS_TRILINOS_HAVE_MPI */
 
-/* CVODE should use fused kernels if utilizing
-  * the CUDA NVector.
-  */
-/* #undef SUNDIALS_BUILD_PACKAGE_FUSED_KERNELS */
-
-
-/* BUILD SUNDIALS with monitoring functionalities
-  * the CUDA NVector.
-  */
-/* #undef SUNDIALS_BUILD_WITH_MONITORING */
-
+/* RAJA backends */
+#define SUNDIALS_RAJA_BACKENDS_CUDA
+/* #undef SUNDIALS_RAJA_BACKENDS_HIP */
+/* #undef SUNDIALS_RAJA_BACKENDS_SYCL */
 
 /* ------------------------------------------------------------------
  * SUNDIALS modules enabled
  * -----------------------------------------------------------------*/
 
-
 #define SUNDIALS_ARKODE 1
 #define SUNDIALS_CVODE 1
 #define SUNDIALS_CVODES 1
@@ -144,7 +172,7 @@
  * -----------------------------------------------------------------*/
 
 
-/* FCMIX: Define Fortran name-mangling macro for C identifiers.
+/* Define Fortran name-mangling macro for C identifiers.
  * Depending on the inferred scheme, one of the following six
  * macros will be defined:
  *     #define SUNDIALS_F77_FUNC(name,NAME) name
@@ -154,20 +182,20 @@
  *     #define SUNDIALS_F77_FUNC(name,NAME) NAME ## _
  *     #define SUNDIALS_F77_FUNC(name,NAME) NAME ## __
  */
-#define SUNDIALS_F77_FUNC(name,NAME) name ## _
 
-/* FCMIX: Define Fortran name-mangling macro for C identifiers
- *        which contain underscores.
+
+/* Define Fortran name-mangling macro for C identifiers
+ * which contain underscores.
  */
-#define SUNDIALS_F77_FUNC_(name,NAME) name ## _
 
-/* FNVECTOR: Allow user to specify different MPI communicator
+
+/* Allow user to specify different MPI communicator
  * If it was found that the MPI implementation supports MPI_Comm_f2c, then
  *      #define SUNDIALS_MPI_COMM_F2C 1
  * otherwise
  *      #define SUNDIALS_MPI_COMM_F2C 0
  */
-#define SUNDIALS_MPI_COMM_F2C 1
+
 
 
 /* ------------------------------------------------------------------
@@ -182,8 +210,12 @@
 #endif
 
 #ifndef SUNDIALS_C_INLINE
+#ifndef __STDC_VERSION__ /* must be c89 or c90 */
+#define SUNDIALS_C_INLINE
+#else
 #define SUNDIALS_C_INLINE inline
 #endif
+#endif
 
 #ifdef __cplusplus
 #define SUNDIALS_INLINE SUNDIALS_CXX_INLINE
@@ -194,3 +226,5 @@
 /* Mark SUNDIALS function as static inline.
  */
 #define SUNDIALS_STATIC_INLINE static SUNDIALS_INLINE
+
+#endif /* _SUNDIALS_CONFIG_H */
